@@ -13,15 +13,15 @@ from pendulum.datetime import DateTime
 from pendulum.parser import parse
 
 
-class CattrConverter(cattr.Converter):  # type: ignore
+class CattrConverter(cattr.Converter):
     """
     Cattr converter that knows how to correctly serialize/deserialize DateTime to an ISO 8601 timestamp.
     """
 
     def __init__(self) -> None:
-        super().__init__()
+        super().__init__()  # type: ignore
         self.register_unstructure_hook(DateTime, lambda datetime: datetime.isoformat() if datetime else None)
-        self.register_structure_hook(DateTime, lambda string, _: parse(string) if string else None)
+        self.register_structure_hook(DateTime, lambda string, _: parse(string) if string else None)  # type: ignore
 
 
 T = TypeVar("T")  # pylint: disable=invalid-name
